@@ -28,7 +28,7 @@
 	#include <cstring>              // need both string and cstring for GCC
 #endif
 
-#define ASTYLE_VERSION "3.6.7"
+#define ASTYLE_VERSION "3.6.9"
 
 namespace astyle {
 
@@ -220,7 +220,7 @@ public:
 	static void buildHeaders(std::vector<const std::string*>* headers, int fileType, bool beautifier = false);
 	static void buildIndentableMacros(std::vector<const std::pair<const std::string, const std::string>* >* indentableMacros);
 	static void buildIndentableHeaders(std::vector<const std::string*>* indentableHeaders);
-	static void buildNonAssignmentOperators(std::vector<const std::string*>* nonAssignmentOperators);
+	static void buildNonAssignmentOperators(std::vector<const std::string*>* nonAssignmentOperators, int fileType);
 	static void buildNonParenHeaders(std::vector<const std::string*>* nonParenHeaders, int fileType, bool beautifier = false);
 	static void buildOperators(std::vector<const std::string*>* operators, int fileType);
 	static void buildPreBlockStatements(std::vector<const std::string*>* preBlockStatements, int fileType);
@@ -396,6 +396,9 @@ protected:
 	int  runInIndentContinuation;
 	int  nonInStatementBrace;
 	int  objCColonAlignSubsequent;		// for subsequent lines not counting indent
+	int  bracesNestingLevel;
+	int  bracesNestingLevelOfStruct;
+
 	bool lineCommentNoBeautify;
 	bool isElseHeaderIndent;
 	bool isCaseHeaderCommentIndent;
@@ -937,7 +940,7 @@ private:  // variables
 	int  templateDepth;
 	int  squareBracketCount;
 	int  parenthesesCount;
-	int  bracesNestingLevel;
+
 	size_t  squeezeEmptyLineNum;
 	size_t  squeezeEmptyLineCount;
 
